@@ -19,7 +19,6 @@
  *
  */
 
-#define PY_SSIZE_T_CLEAN 
 #include <Python.h>
 
 #include <stdbool.h>
@@ -129,7 +128,7 @@ static PyObject *qdbpy_write(QdbHandle *self, PyObject *args)
     qdb_handle_t qdb = qdbhandle(self);
     char *path;
     char *data;
-    Py_ssize_t data_len;
+    int data_len;
     bool result;
 
     if (!qdb)
@@ -170,7 +169,7 @@ static PyObject *qdbpy_list(QdbHandle *self, PyObject *args)
     Py_END_ALLOW_THREADS
 
     if (list) {
-        unsigned int i;
+        int i;
         PyObject *val = PyList_New(list_len);
         for (i = 0; i < list_len; i++) {
 #if PY_VERSION_HEX >= 0x03000000
@@ -213,7 +212,7 @@ static PyObject *qdbpy_multiread(QdbHandle *self, PyObject *args)
     Py_END_ALLOW_THREADS
 
     if (values) {
-        unsigned int i;
+        int i;
         PyObject *val = PyDict_New();
         for (i = 0; i < list_len; i++) {
             PyDict_SetItemString(val,
@@ -401,7 +400,7 @@ static int parse_handle_path(QdbHandle *self, PyObject *args,
                                   qdb_handle_t *qdb,
                                   char **path)
 {
-    size_t path_len;
+    int path_len;
     *qdb = qdbhandle(self);
 
     if (!qdb)
